/* ------------------------------------------------------------------------------------------------------

   Grappelli 2.0
   * http://code.google.com/p/django-grappelli/

   Based on Django Admin Interface
   * http://www.djangoproject.com

   Developed for Mozilla Firefox 3.0.1+ & Safari 3.5+ / using CSS 3 Specifications

   * See README for instructions on how to use Grappelli.
   * For credits and origins, see AUTHORS.

   * Copyright (c) 2008-2009, vonautomatisch werkstaetten. All rights reserved.
     See LICENSE for more info.

------------------------------------------------------------------------------------------------------ */
@import url('reset.css');
@import url('typography.css');
@import url('modules.css');
@import url('tables.css');
@import url('forms.css');
@import url('widgets.css');

/*  Loads background-gradients for webkit browsers (Safari etc.)
    Comment out the following css-import if you want to use Grappelli without gradients */
@import url('webkit-gradients.css');



/*  Body
------------------------------------------------------------------------------------------------------ */

body {
    margin: 0; padding: 0;
    font-family: Arial, sans-serif;
    font-size: 12px; line-height: 16px;
    color: #444;
    background: #fff;
}



/*  Header
------------------------------------------------------------------------------------------------------ */

#header {
    position: fixed; top: 0; z-index: 1100;
    width: 100%; height: 30px;
    color: #eee; font-size: 11px; line-height: 14px; font-weight: bold;
    background: #333;
}
#header a:hover, #header a:active {
    color: #ddd;
}

body.filebrowser.popup #header {
    display: none;
}



/*  Branding, Bookmarks & User-Tools
------------------------------------------------------------------------------------------------------ */

.branding, .admin-title, #bookmarks li, #user-tools li {
    margin: 0; padding: 8px 10px;
}
.branding {
    display: none;
    position: relative; float: right;
    width: 10px;
    border-left: 1px solid #343434;
    background: url('../img/grappelli-icon.png') 50% 50% no-repeat;
    background-color: #262626;
}
.admin-title {
    position: relative; float: left;
    padding-left: 15px;
    padding-right: 10px;
    border-left: 1px solid #404040;
    border-right: 1px solid #262626;
}

#header ul li {
    position: relative; float: left;
}


/*  Bookmarks ................................................... */

ul#bookmarks {
    position: relative; float: left;
    border-left: 1px solid #404040;
    border-right: 1px solid #404040;
}
ul#bookmarks li {
    padding: 8px 10px;
}
ul#bookmarks li:last-child {
    border-right: 1px solid #262626;
}

ul#bookmarks li#toggle-bookmarks-listing {
    width: 175px;
    cursor: pointer;
}
ul#bookmarks li#toggle-bookmarks-listing:hover>a {
    color: #eee;
}
ul#bookmarks li.action {
    padding: 3px 0 2px;
}
ul#bookmarks li.action:last-child {
    padding-right: 5px;
}


/*  Bookmarks Actions ................................................... */

ul#bookmarks li.action a {
    position: relative; display: block;
    margin: 0;
    width: 18px; height: 22px;
    border: 1px solid transparent;
    -moz-border-radius: 3px; -webkit-border-radius: 3px; border-radius: 3px;
    background-position: 50% 50%;
    background-repeat: no-repeat;
}
ul#bookmarks li.action {
    width: 20px; height: 24px;
    background-position: 50% 9px;
    background-repeat: no-repeat;
}
ul#bookmarks li.action.bookmark-add {
    background-image: url('../img/icons/icon-bookmark_add-inactive.png');
}
ul#bookmarks li.action.bookmark-remove {
    background-image: url('../img/icons/icon-bookmark_remove-inactive.png');
}
ul#bookmarks li.action.active {
    background-image: none;
}

ul#bookmarks li.action.bookmark-add.active a:link, ul#bookmarks li.action.bookmark-add.active a:visited {
    background-image: url('../img/icons/icon-bookmark_add.png');
}
ul#bookmarks li.action.bookmark-add.active a:hover, ul#bookmarks li.action.bookmark-add.active a:active {
    background-image: url('../img/icons/icon-bookmark_add-hover.png');
}
ul#bookmarks li.action.bookmark-remove.active a:link, ul#bookmarks li.action.bookmark-remove.active a:visited {
     background-image: url('../img/icons/icon-bookmark_remove.png');
}
ul#bookmarks li.action.bookmark-remove.active a:hover, ul#bookmarks li.action.bookmark-remove.active a:active {
    background-image: url('../img/icons/icon-bookmark_remove-hover.png');
}
ul#bookmarks li.action a.bookmark-manage:link, ul#bookmarks li.action a.bookmark-manage:visited {
    background-image: url('../img/icons/icon-bookmark_manage.png');
}
ul#bookmarks li.action a.bookmark-manage:hover, ul#bookmarks li.action a.bookmark-manage:active {
    background-image: url('../img/icons/icon-bookmark_manage-hover.png');
}


/*  Bookmarks Listing ................................................... */

ul#bookmarks-listing {
    display: none;
    position: absolute; z-index: 1000; top: 30px; left: -1px; float: none;
    margin: 0;
    width: 260px;
    border: 1px solid #404040;
    -moz-border-radius-bottomleft: 5px; -webkit-border-bottom-left-radius: 5px; border-bottom-left-radius: 5px;
    -moz-border-radius-bottomright: 5px; -webkit-border-bottom-right-radius: 5px; border-bottom-right-radius: 5px;
    background: #333;
    -moz-box-shadow: 0 0 10px #333; -webkit-box-shadow: 0 0 10px #333; box-shadow: 0 0 10px #333;
}
ul#bookmarks-listing li {
    float: none;
    padding: 0;
    border-bottom: 1px solid #4d4d4d;
}
ul#bookmarks-listing li:last-child {
    border: none;
}

ul#bookmarks li p {
    padding: 5px 10px;
}

ul#bookmarks-listing li a:link, ul#bookmarks-listing li a:visited {
    display: block;
    padding: 5px 30px 5px 10px;
    background: #333;
}
ul#bookmarks-listing li a:hover, ul#bookmarks-listing li a:active {
    color: #eee;
    background: #309bbf;
}
ul#bookmarks-listing li:last-child a {
    -moz-border-radius-bottomleft: 3px; -webkit-border-bottom-left-radius: 3px; border-bottom-left-radius: 3px;
    -moz-border-radius-bottomright: 3px; -webkit-border-bottom-right-radius: 3px; border-bottom-right-radius: 3px;
}


/*  Add Bookmark ................................................... */

#bookmark-add {
    display: none;
    position: absolute; z-index: 1000; top: 30px; left: -196px;
    margin: 0; padding: 10px;
    width: 240px;
    border: 1px solid #404040;
    -moz-border-radius-bottomleft: 5px; -webkit-border-bottom-left-radius: 5px; border-bottom-left-radius: 5px;
    -moz-border-radius-bottomright: 5px; -webkit-border-bottom-right-radius: 5px; border-bottom-right-radius: 5px;
    background: #333;
    -moz-box-shadow: 0 0 10px #333; -webkit-box-shadow: 0 0 10px #333; box-shadow: 0 0 10px #333;
}
#bookmark-add input[type=text] {
    margin-bottom: 10px;
    width: 234px;
    border: none;
}
#bookmark-add input[type=submit],
#bookmark-add-cancel {
    position: relative;
    height: 25px;
    font-size: 11px;
}
#bookmark-add input[type=submit] {
    float: right;
}
#bookmark-add-cancel {
    float: left;
    background: #444;
}
#bookmark-add input[type=submit]:hover,
#bookmark-add-cancel:hover {
    background: #666;
}


/*  User Tools ................................................... */

#user-tools {
    position: absolute;
/*    right: 31px;*/
    right: -1px;
    border-left: 1px solid #262626;
}
#user-tools li {
    border-left: 1px solid #404040;
    border-right: 1px solid #262626;
}



/*  Breadcrumbs
------------------------------------------------------------------------------------------------------ */

div.breadcrumbs {
    position: fixed; top: 30px; z-index: 1000;
    width: 100%;
    padding: 3px 8px 3px 15px;
    color: #666; font-size: 11px; font-weight: normal; text-align: left;
    border-top: 1px solid #ccc;
    border-bottom: 1px solid #ccc;
    background: #e6e6e6;
}
body.popup div.breadcrumbs {
    top: 0;
}



/*  Messages
------------------------------------------------------------------------------------------------------ */

ul.messagelist {
    position: relative; top: 54px; z-index: 1001;
}
ul.messagelist li {
    display: block;
    font-size: 11px; font-weight: bold;
    padding: 5px 0 5px 30px;
    border-bottom: 1px solid #ddd;
    background: #fcfce7 url('../img/icons/icon-yes.png') 15px 50% no-repeat;
}
ul.messagelist.success li {
	background: #C0E1C0 url('../img/icons/icon-yes.png') 15px 50% no-repeat;
}
ul.messagelist.error li {
	background: #E1C0C0 url('../img/icons/icon-yes.png') 15px 50% no-repeat;
}
body.popup .breadcrumbs + ul.messagelist {
    top: 24px;
}



/*  Container, Content & Footer
------------------------------------------------------------------------------------------------------ */

#container {
    z-index: 0;
    position: relative;
    width: 100%;
    min-width: 760px;
    padding: 0;
}
#content {
    margin: 80px 15px;
}
body.popup #content {
    margin-top: 0;
}
body.popup .breadcrumbs + #content,
body.popup ul.messagelist + #content {
    margin-top: 50px;
}

#content-main {
    float: left;
    min-width:100%;
}
#content-related {
    position: relative; float: right;
    margin-right: -38em;
    width: 18em;
}
#content-related-extended {
    position: relative; float: right;
    margin-right: -19em;
    width: 18em;
}
#footer {
    clear: both;
    padding: 10px;
}



/*  Column Types
------------------------------------------------------------------------------------------------------ */

.colMS {
    margin-right: 20em !important;
}
.colSM {
    margin-left: 20em !important;
}
.colSM #content-related {
    float: left;
    margin-right: 0;
    margin-left: -19em;
}
.colSM #content-main {
    float: right;
}
.popup .colM {
    width: 95%;
}
.subcol {
    float: left;
    width: 46%;
    margin-right: 15px;
}



/*  Object Tools
------------------------------------------------------------------------------------------------------ */

.object-tools {
    position: relative; float: right; z-index: 800;
    margin: -36px 0 -35px; padding: 0;
    font-weight: bold;
}
.form-row .object-tools {
    float: none;
    margin-top: 5px; margin-bottom: 5px;
}
.object-tools li {
    float: left;
    margin: 0 0 0 5px; padding: 0;
}
.object-tools a {
    display: block;
    margin: 0; padding: 5px 10px;
    height: 16px;
    font-size: 11px;
    -moz-border-radius: 5px; -webkit-border-radius: 5px; border-radius: 5px;
}
.object-tools a:link, .object-tools a:visited {
    color: #666;
    background: #ddd;
}
.object-tools a:hover, .object-tools a:active {
    color: #fff;
    background: #444;
}


/*  Focused Buttons ................................................... */

.object-tools a.focus:link, .object-tools a.focus:visited {
    color: #fff;
    background: #444;
}
.object-tools a.focus:hover, .object-tools a.focus:active {
    background: #309bbf;
}
