{% load i18n %}

{% if show and choices %}
<div class="module date-hierarchy">
    <h2>{% trans 'Date Hierarchy' %}</h2>
    <ul class="date_hierarchy">
        {% if back %}<li class="form-row narrow date-back"><a href="{{ back.link }}">&lsaquo; {{ back.title }}</a></li>{% endif %}
        {% for choice in choices %}
        <li class="form-row narrow">{% if choice.link %}<a href="{{ choice.link }}">{% endif %}{{ choice.title }}{% if choice.link %}</a>{% endif %}</li>
        {% endfor %}
    </ul>
</div>
{% endif %}
