<fieldset class="module aligned {{ fieldset.classes }}">
  {% if fieldset.name %}<h4>{{ fieldset.name }}</h4>{% endif %}
  {% if fieldset.description %}<div class="description">{{ fieldset.description|safe }}</div>{% endif %}
  {% for line in fieldset %}
      <div class="item form-row{% if line.errors %} errors{% endif %} {% for field in line %}{{ field.field.name }} {% endfor %} ">
      {{ line.errors }}
      {% for field in line %}
      <div{% if not line.fields|length_is:"1" %} class="field-box"{% endif %}> 
          {% if field.is_readonly %}
              {{ field.label_tag }}{{ field.contents }}
          {% else %}
              {% if field.is_checkbox %}
                  {{ field.field }}{{ field.label_tag }}
              {% else %}
                  {{ field.label_tag }}{{ field.field }}
              {% endif %}
          {% endif %}
          {% if field.field.field.help_text %}<p class="help">{{ field.field.field.help_text|safe }}</p>{% endif %}
      </div>
      {% endfor %}
      </div>
  {% endfor %}
</fieldset>
