{% extends "admin/base_site.html" %}
{% load adminmedia %}
{% load i18n %}
{% block stylesheets %}
    {{ block.super }}
    <link rel="stylesheet" type="text/css" href="{% admin_media_prefix %}css/documentation.css" />
{% endblock %}
{% block bodyclass %}documentation{% endblock %}
{% block breadcrumbs %}<div class="breadcrumbs"><a href="../../../">Home</a> &rsaquo; <a href="../../">Documentation</a> &rsaquo; <a href="../">Views</a> &rsaquo; {{ name }}</div>{% endblock %}
{% block title %}View: {{ name }}{% endblock %}

{% block content %}
<h1>{{ name }}</h1>

<div id="content-main" class="rte">
<h2 class="subhead">{{ summary }}</h2>

<p>{{ body }}</p>

{% if meta.Context %}
<h3>Context:</h3>
<p>{{ meta.Context }}</p>
{% endif %}

{% if meta.Templates %}
<h3>Templates:</h3>
<p>{{ meta.Templates }}</p>
{% endif %}

<a href="../" class="back">&lsaquo; Back to Views Documentation</a>
</div>
{% endblock %}
