{% extends "admin/base_site.html" %}
{% load i18n %}
{% block userlinks %}
{% url django-admindocs-docroot as docsroot %}{% if docsroot %}
<li>
    <a href="{{ docsroot }}">{% trans 'Documentation' %}</a>
</li>
{% endif %}
<li>
    <a href="{{ root_path }}password_change/">{% trans 'Change password' %}</a>
</li>
<li>
    <a href="{{ root_path }}logout/">{% trans 'Log out' %}</a>
</li>
{% endblock %}

{% block breadcrumbs %}<div class="breadcrumbs"><a href="../../">{% trans 'Home' %}</a> &rsaquo; {% trans 'Password change' %}</div>{% endblock %}

{% block title %}{% trans 'Password change successful' %}{% endblock %}

{% block content %}

<h1>{% trans 'Password change successful' %}</h1>

<p>{% trans 'Your password was changed.' %}</p>

{% endblock %}
