{% load i18n %}

<div id="content-related-extended">
    <div class="module">
        <h2>{% trans "Navigation" %}</h2>
        {% if object_list %}
        {% for object in object_list %}
        {% ifchanged object.navigation %}
        {% if not forloop.first %}</ul>{% endif %}
        <h3>{{ object.navigation }}</h3>
        <ul class="menulist">
        {% endifchanged %}
        <li><a href="{{ object.link }}" class="{{ object.get_category_display }}"{% ifequal object.get_category_display "external" %} target="_blank"{% endifequal %}>{{ object }}</a></li>
        {% endfor %}
        {% else %}
        <h3>{% trans "No Items Found." %}</h3>
        {% endif %}
    </div>
</div>
