


/*  Login Form
------------------------------------------------------------------------------------------------------ */

body.login {
    background: #fff;
}
body.login .errornote {
    position: relative; top: 30px;
    margin: 0 -1px;
    -moz-border-radius: 0; -webkit-border-radius: 0;
}
.login #content {
    margin: 0;
    overflow: hidden;
}

.login #content-main,
.login .submit-row {
    float: none;
    margin: 0 auto;
    width: 360px;
}
.login #content-main {
    margin-top: 80px;
    margin-bottom: 20px;
    border: 1px solid #d4d4d4;
    -moz-border-radius: 5px; -webkit-border-radius: 5px; border-radius: 5px;
    background: #eee;
    min-width:360px;
}

.login .form-row label {
    display: block; float: left;
    padding: 0 10px 6px 0;
    width: 120px;
}
.login .form-row #id_username, .login .form-row #id_password {
    width: 192px;
}

.login span.help {
    font-size: 10px;
    display: block;
}

.login .submit-row * {
    margin-right: -1px;
}

