


/*  Dashboard
------------------------------------------------------------------------------------------------------ */

.dashboard #content {
    width: 500px;
}
.dashboard .module {
    margin-bottom: 3px;
}
.dashboard .module:last-child {
    margin-bottom: 0;
}



/*  Dashboard Group Collapsible
------------------------------------------------------------------------------------------------------ */

.dashboard .group-collapsible {
    position: relative;
    margin: 0 0 7px;
    padding: 2px;
    -moz-border-radius: 7px; -webkit-border-radius: 7px; border-radius: 7px;
}

.dashboard .group-collapsible.collapse-closed .module {
    display: none;
}
.dashboard .group-collapsible.collapse-open, 
.dashboard .group-collapsible.collapse-closed:hover {
    border: 2px solid #d4d4d4 !important;
}
.dashboard .group-collapsible.collapse-closed {
    border: 2px solid #e4e4e4 !important;
}
.dashboard .group-collapsible h2 {
    margin: 0 0 3px;
    padding: 7px 5px 6px 10px;
    font-size: 12px; line-height: 16px; font-weight: bold;
    border: 1px solid #ccc;
    -moz-border-radius: 5px; -webkit-border-radius: 5px; border-radius: 5px;
    background-color: #e6e6e6;
}
.dashboard .group-collapsible.collapse-closed h2 {
    margin: 0;
}

.dashboard .group-collapsible.collapse-closed h2.collapse-toggle {
    text-shadow: 1px 1px #bcdfeb;
    background-color: #a0d8eb;
    background-color: #c0e1ec;
    background-image: url('../img/icons/icon_fieldset_collapse-closed.png');
}
.dashboard .group-collapsible.collapse-closed h2.collapse-toggle:hover, 
.dashboard .group-collapsible.collapse-open h2.collapse-toggle {
    text-shadow: 1px 1px #bcdfeb;
    background-color: #c0e1ec;
    background-image: url('../img/icons/icon_fieldset_collapse-open.png');
}
.dashboard .group-collapsible table caption {
    padding: 5px 10px;
}



/*  Dashboard Table Settings
------------------------------------------------------------------------------------------------------ */

.dashboard .module table {
    border-right: none;
}
.dashboard .module table + table {
    border-top: 1px solid #e0e0e0;
}
.dashboard .module table th {
    width: 100%;
}

.dashboard .module table th.application {
    background: #e6e6e6;
}

.dashboard .module table tbody:only-child tr:first-child *:first-child {
    -moz-border-radius-topleft: 4px; -webkit-border-top-left-radius: 4px; border-top-left-radius: 4px;
}
.dashboard .module table tbody:only-child tr:first-child *:last-child {
    -moz-border-radius-topright: 4px; -webkit-border-top-right-radius: 4px; border-top-right-radius: 4px;
}


.dashboard .module table td {
    white-space: nowrap;
}

.dashboard .module table td a {
    display: block;
    padding-right: 0;
}



/*  Navigation & Recent Actions (Content-Related & Content-Related-Extended)
------------------------------------------------------------------------------------------------------ */

#content-related, #content-related-extended {
    color: #444; font-size: 11px;
}

#content-related h3, #content-related-extended h3, 
#content-related h4, #content-related-extended h4 {
    padding: 5px 10px;
    font-size: 11px;
}

#content-related p, 
#content-related-extended p {
    border-top: 1px solid #ddd;
    padding: 3px 10px 8px;
    color: #999; font-style: italic;
}

.module ul.menulist, 
.module ul.actionlist {
    margin: 0; padding: 0;
    border-top: 1px solid #ddd;
    list-style-type: none;
}
.module ul.actionlist {
    padding-bottom: 3px;
}
ul.menulist li:last-child {
    border-bottom-color: #ddd;
}
ul.menulist:last-child li:last-child, 
ul.actionlist:last-child li:last-child {
    margin-bottom: 5px;
    border-bottom: none;
}


/*  Navigation ................................................... */

ul.menulist li {
    margin: 0; padding: 3px 10px 3px 9px;
    border-bottom: 1px solid #eee;
    list-style-type: none;
}
ul.menulist li a {
    padding-left: 12px;
    font-weight: bold;
    background-color: transparent;
    background-position: 2px 50%;
    background-repeat: no-repeat;
}
ul.menulist li a.external {
    background-position: 0 3px;
}
ul.menulist li a.internal:link, ul.menulist li a.internal:visited {
    background-image: url('../img/icons/icon-menulist_internal.png');
}
ul.menulist li a.internal:hover, ul.menulist li a.internal:active {
    color: #666;
    background-image: url('../img/icons/icon-menulist_internal-hover.png');
}
ul.menulist li a.external:link, ul.menulist li a.external:visited {
    color: #83c3d9;
    background-image: url('../img/icons/icon-menulist_external.png');
}
ul.menulist li a.external:hover, ul.menulist li a.external:active {
    color: #666;
    background-image: url('../img/icons/icon-menulist_external-hover.png');
}


/*  Recent Actions ................................................... */

ul.actionlist li {
    margin: 5px 0 0; padding: 2px 10px 0 25px;
    line-height: 12px;
}
ul.actionlist li a {
    margin-left: -14px; padding-left: 13px;
    background-position: 0 50%;
    background-repeat: no-repeat;
}

ul.actionlist li.addlink a:link, ul.actionlist li.addlink a:visited {
    background-image:url('../img/icons/icon-actionlist_addlink.png');
}
ul.actionlist li.addlink a:hover, ul.actionlist li.addlink a:active {
    background-image:url('../img/icons/icon-actionlist_addlink-hover.png');
}
ul.actionlist li.changelink a:link, ul.actionlist li.changelink a:visited {
    background-image:url('../img/icons/icon-actionlist_changelink.png');
}
ul.actionlist li.changelink a:hover, ul.actionlist li.changelink a:active {
    background-image:url('../img/icons/icon-actionlist_changelink-hover.png');
}

ul.actionlist li.deletelink {
    color: #666; text-decoration: line-through;
    background: url('../img/icons/icon-actionlist_deletelink.png') 11px 5px no-repeat;
}
