input.field, select.field {width:200px;}
input.picker {width:179px; margin-left: 5px;}
input.disabled {border-color:#F2F2F2;}
img.picker {vertical-align:text-bottom; cursor:pointer;}
h1 {padding: 0 0 5px 0;}
.panel_wrapper div.current {height:160px;}
#xhtmlxtrasdel .panel_wrapper div.current, #xhtmlxtrasins .panel_wrapper div.current {height: 230px;}
a.browse span {display:block; width:20px; height:20px; background:url('../../../themes/advanced/img/icons.gif') -140px -20px;}
#datetime {width:180px;}
