{% extends "admin/base_site.html" %}

<!-- LOADING -->
{% load i18n grp_csrf %}

<!-- BREADCRUMBS -->
{% block breadcrumbs %}
<div class="breadcrumbs">
     <a href="../../">{% trans "Home" %}</a> &rsaquo;
     <a href="../">{{ app_label|capfirst }}</a> &rsaquo;
     <a href="./">{{ opts.verbose_name_plural|capfirst }}</a> &rsaquo;
     {% trans 'Delete multiple objects' %}
</div>
{% endblock %}

<!-- CONTENT -->
{% block content %}
{% if perms_lacking %}
    <p>{% blocktrans %}Deleting the {{ object_name }} would result in deleting related objects, but your account doesn't have permission to delete the following types of objects:{% endblocktrans %}</p>
    <ul>
    {% for obj in perms_lacking %}
        <li>{{ obj }}</li>
    {% endfor %}
    </ul>
{% else %}
    <p>{% blocktrans %}Are you sure you want to delete the selected {{ object_name }} objects? All of the following objects and it's related items will be deleted:{% endblocktrans %}</p>
    {% for deleteable_object in deletable_objects %}
        <ul>{{ deleteable_object|unordered_list }}</ul>
    {% endfor %}
    <form action="" method="post">{% grp_csrf_token %}
        <div class="submit-row">
            {% for obj in queryset %}
            <input type="hidden" name="{{ action_checkbox_name }}" value="{{ obj.pk }}" />
            {% endfor %}
            <input type="hidden" name="action" value="delete_selected" />
            <input type="hidden" name="post" value="yes" />
            <p class="cancellink-box"><a href="../" class="cancellink">{% trans "Cancel" %}</a></p>
            <input type="submit" class="default" value="{% trans "Yes, I'm sure" %}" />
        </div>
    </form>
{% endif %}
{% endblock %}