<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" lang="{{ LANGUAGE_CODE }}" xml:lang="{{ LANGUAGE_CODE }}" {% if LANGUAGE_BIDI %}dir="rtl"{% endif %}>
<head>
<title>{% block title %}{% endblock %}</title>
{% block blockbots %}<meta name="robots" content="NONE,NOARCHIVE" />{% endblock %}

<!-- LOADING -->
{% load adminmedia i18n grp_tags %}

<!-- STYLESHEETS / EXTRASTYLE -->
{% block stylesheets %}
    <link rel="stylesheet" type="text/css" href="{% admin_media_prefix %}css/base.css" />
    {% if LANGUAGE_BIDI %}<link rel="stylesheet" type="text/css" href="{% block stylesheet_rtl %}{% admin_media_prefix %}css/rtl.css{% endblock %}" />{% endif %}
{% endblock %}
{% block extrastyle %}{% endblock %}

<!-- JAVASCRIPTS / EXTRAHEAD -->
{% block javascripts %}
    <script type="text/javascript" src="{% admin_media_prefix %}jquery/jquery-1.3.2.min.js"></script>
    <script type="text/javascript">
        // Admin URL
        var ADMIN_URL = "{% get_admin_url %}";
        // Generic Relations
        {% get_generic_relation_list %}
        // Get Bookmarks
    </script>
{% endblock %}
{% block extrahead %}{% endblock %}

</head>

<body class="{% if is_popup %}popup {% endif %}{% block bodyclass %}{% endblock %}">

<!-- CONTAINER -->
<div id="container">

    <!-- HEADER -->
    {% if not is_popup %}
    {% include "admin/includes_grappelli/header.html" %}
    {% endif %}

    <!-- BREADCRUMBS -->
    {% block breadcrumbs %}<div class="breadcrumbs"><a href="/">{% trans 'Home' %}</a>{% if title %} &rsaquo; {{ title }}{% endif %}</div>{% endblock %}

    <!-- MESSAGES -->
    {% if messages %}
    <ul class="messagelist">{% for message in messages %}<li>{{ message }}</li>{% endfor %}</ul>
    {% endif %}
    <!-- GRAPPELLI MESSAGES -->
    {% if request %}{% get_messages request.session %}{% endif %}

    <!-- CONTENT -->
    <div id="content" class="{% block coltype %}colM{% endblock %}">
        {% block pretitle %}{% endblock %}
        {% block content_title %}{% if title %}<h1>{{ title }}</h1>{% endif %}{% endblock %}
        {% block content %}
        {% block object-tools %}{% endblock %}
        {{ content }}
        {% endblock %}
        {% block sidebar %}{% endblock %}
        <br class="clear" />
    </div>

    <!-- FOOTER -->
    {% block footer %}<div id="footer"></div>{% endblock %}

</div>
</body>
</html>
